#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mime-types
version:              0.1.0.9
visibility:           public
id:                   mime-types-0.1.0.9-2ORfbvGCmlz3ckhb8dUDtI
key:                  mime-types-0.1.0.9-2ORfbvGCmlz3ckhb8dUDtI
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             https://github.com/yesodweb/wai
synopsis:             Basic mime-type handling types and functions
description:
    API docs and the README are available at <http://www.stackage.org/package/mime-types>.

category:             Web
abi:                  b83f1e57ad4b057a776042d8731033d6
exposed:              True
exposed-modules:      Network.Mime
import-dirs:          /usr/lib/ghc-8.10.5/site-local/mime-types-0.1.0.9
library-dirs:         /usr/lib/ghc-8.10.5/site-local/mime-types-0.1.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/mime-types-0.1.0.9
hs-libraries:         HSmime-types-0.1.0.9-2ORfbvGCmlz3ckhb8dUDtI
depends:
    base-4.14.2.0 bytestring-0.10.12.0 containers-0.6.4.1 text-1.2.4.1

haddock-interfaces:   /usr/share/doc/haskell-mime-types/html/mime-types.haddock
haddock-html:         /usr/share/doc/haskell-mime-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

